@@ -39,10 +39,6 @@ from tkinter import ttk
 from PIL import Image, ImageTk, ImageGrab
 from PIL.PngImagePlugin import PngImageFile, PngInfo
 
-try:
-    from aai_engine_package.screenshot_taker import ScreenShotTaker
-except:
-    from src.aai_engine_package.screenshot_taker import ScreenShotTaker
 
 import zmq
 
@@ -53,8 +49,6 @@ ZMQ_PORT = 5555
 ZMQ_MSG_TYPE_PROGRESS = "progress"
 ZMQ_MSG_TYPE_DATA = "data"
 
-NORMAL_SCREENSHOT = 0
-OCR_SCREENSHOT = 1
 
 pyautogui.FAILSAFE = True
 
@@ -65,13 +59,6 @@ REL_PATH = "my_screenshot.png"
 abs_file_path = os.path.join(script_dir, REL_PATH)
 SCREENSHOT = abs_file_path
 
-dirname = os.path.dirname(__file__)
-if os.name == "posix":
-    icon_path = os.path.join(dirname, r'style/icon.ico')
-    theme_path = os.path.join(dirname, r'style/sun-valley.tcl')
-else:
-    icon_path = os.path.join(dirname, r'style\icon.ico')
-    theme_path = os.path.join(dirname, r'style\sun-valley.tcl')
 
 # Global variables to check if internal display is used as main display on OSX. Needed because of bug which causes the
 # screen resolution to be doubled when said condition is met.
@@ -122,7 +109,7 @@ def log(filename, line, time=True):
 
 class TaskWrapper():
     """
-    Task wrapper class to control execution
+    Task wrapper class to control execution of task
     """
 
     def __init__(self, task_id, name, cwd, script, scheduled_time, execution_type=-1, priority=15, trigger=lambda _: True):
@@ -162,6 +149,7 @@ class TaskWrapper():
                 shell=False
             )
             return process
+
     def __str__(self) -> str:
         """str format for TaskWrapper"""
         if self.execution_type == 'SC':
@@ -230,6 +218,9 @@ class Task():
         global USING_INTERNAL_DISPLAY_AS_MAIN_ON_OSX
         USING_INTERNAL_DISPLAY_AS_MAIN_ON_OSX = internal_display_used_as_main_on_osx()
 
+        self._log_execution("STARTING TASK EXECUTION")
+
+
         if self.script is None:
             self.error = False
             if not self.standalone:
@@ -884,138 +875,4 @@ def read_excel(path, task=None):
         Dict: A dictionary that contains the information in the excel file
     """
     print(f"{datetime.strftime(datetime.now(), '%H:%M:%S')}: Reading in excel data from {path}")
-    return pd.read_excel(path).to_dict(orient='records')
-
-
-def cli():
-    """_summary_
-    """
-    if len(sys.argv) == 2:
-        save_location = sys.argv[1]
-        print(os.getcwd(), save_location)
-    print("Called aai-engine-capture")
-    main(save_location)
-
-def test_edit(save_location, param2):
-    """Edit stub
-    """
-    pass
-
-
-def edit(save_location, haystack):
-    """Calls the edit routine
-    """
-    main(save_location, haystack, editing=True)
-
-
-def main(save_location, update_function_after_edit=None, needle=r"C:\Users\Toto\Documents\AdAstraIndustries\aai_engine\img\cv.png", editing=False, screenshot_type = NORMAL_SCREENSHOT):
-    """main
-    """
-    temp_screenshot = tempfile.NamedTemporaryFile(suffix='.png', delete=False)
-    temp_screenshot_path = temp_screenshot.name
-    if sys.platform == "darwin":
-        temp_screenshot_path = temp_screenshot_path.split(".")[0] + "_000.png"
-    print("TEMP PATH: ", temp_screenshot_path)
-    take_screenshot(temp_screenshot_path)
-
-    root = tkinter.Tk()
-    style = ttk.Style(root)
-    root.wm_colormapwindows()
-
-    root.tk.call('source', theme_path)
-    root.tk.call("set_theme", "dark")
-
-    if editing:
-        print(" - EDIT MODE - ")
-        app = ScreenShotTaker(root, save_location, update_function_after_edit=update_function_after_edit, needle=needle, haystack=temp_screenshot_path,
-                              editing=True)  # When editing from extension
-    else:
-        print(" - CREATE MODE - ")
-        app = ScreenShotTaker(root, save_location, update_function_after_edit=update_function_after_edit, haystack=temp_screenshot_path, editing=False, screenshot_type=screenshot_type)
-
-    root.mainloop()
-    temp_screenshot.close()
-    os.unlink(temp_screenshot.name)
-
-
-class AAIWindow():
-    """AAI window for the GUI
-    """
-    def __init__(self):
-        self.root = tkinter.Tk()
-        style = ttk.Style(self.root)
-        self.root.wm_iconbitmap(icon_path)
-        self.root.wm_colormapwindows()
-        self.root.overrideredirect(True)  # turns off title bar, geometry
-        self.root.geometry('400x100+200+200')  # set new geometry
-
-        # make a frame for the title bar
-        title_bar = tkinter.Frame(self.root, bg='black', relief='flat', bd=2)
-
-        # put a close button on the title bar
-        close_button = ttk.Button(title_bar, text='X', command=self.root.destroy)
-
-        # pack the widgets
-        title_bar.pack(expand=1, fill=tkinter.X)
-        close_button.pack(side=tkinter.RIGHT)
-
-        # bind title bar motion to the move window function
-        title_bar.bind('<B1-Motion>', self.move_window)
-        title_bar.bind('<Button-1>', self.get_pos)
-
-        # root.configure(background='#3E4149')
-        self.root.tk.call('source', theme_path)
-        # root.tk.call('package', 'require', 'awdark')
-        # style.theme_use('dark')
-        self.root.tk.call("set_theme", "dark")
-
-    def move_window(self, event):
-        """_summary_
-
-        Args:
-            event (_type_): _description_
-        """
-        self.root.geometry("400x400" + '+{0}+{1}'.format(event.x_root + self.xwin, event.y_root + self.ywin))
-
-    def get_pos(self, event):
-        """_summary_
-
-        Args:
-            event (_type_): _description_
-        """
-        xwin = self.root.winfo_x()
-        ywin = self.root.winfo_y()
-        startx = event.x_root
-        starty = event.y_root
-
-        self.ywin = ywin - starty
-        self.xwin = xwin - startx
-
-
-def take_screenshot(file_path='my_screenshot.png'):
-    """
-    Take a screenshot.
-    Args:
-
-    """
-    print("Taking screenshot")
-    # time.sleep(3)
-    img = screenshot(file_path)
-    print("Done")
-
-
-def take_screenshot_save(save_location):
-    """
-    Take a screenshot.
-    Args:
-
-    """
-    print("Taking screenshot")
-    # time.sleep(3)
-    save_path = ''.join([save_location, "/img/aai_", ''.join(choice(digits) for i in range(12)), ".png"])
-    img = screenshot(save_path)
-    print("Done")
-
-
-def _get_theme_path():
-    return theme_path
+    return pd.read_excel(path).to_dict(orient='records')
\ No newline at end of file
